# NlpHub

A wrapper around Spacy, NLTK and also uses some other libraries.

pip install NlpHub

## Python Notebook

from NlpHub import Annotators, Transformers, Convertors, Analyzers
Convertors.txt_to_speech("your text here", save_to= "path_to_mp3_file" )

NlpHub is a wrapper around Spacy, NLTK and some other libraries simple NLP tasks. You can perform simple tasks with just 3 or 4 lines of code. NlpHub can perform basic NLP operations with less code and less hassle.

Installation You can install NlpHub via pip. Write this command in terminal and voila, you have installed NlpHub.

pip install NlpHub
It will auto install dependencies and you don't need to worry about anything.

Import
To use NlpHub in your Jupyter notebook or python file, You can import it like this.

from NlpHub import Annotators


Read details here, https://github.com/shahid017/NlpHub
